# Changelog

## 0.8.0 (2026-01-16)

Full Changelog: [v0.7.0...v0.8.0](https://github.com/uselark/lark-billing-python/compare/v0.7.0...v0.8.0)

### Features

* **api:** subscription timelines ([6c1e1a5](https://github.com/uselark/lark-billing-python/commit/6c1e1a5ef6f1de1c901e7bb618c85a10adb83b74))
* **client:** add support for binary request streaming ([6e653ba](https://github.com/uselark/lark-billing-python/commit/6e653ba31dc06313121a435028c897337cf425f3))

## 0.7.0 (2026-01-13)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/uselark/lark-billing-python/compare/v0.6.0...v0.7.0)

### Features

* **api:** add catalog endpoints in schema ([445402e](https://github.com/uselark/lark-billing-python/commit/445402eb71473e19f77426facc3badd5ff10bc47))
* **api:** add rate catalog ([69ebdbc](https://github.com/uselark/lark-billing-python/commit/69ebdbc21295d46957b80fb6450f79adece8d9f2))
* **api:** enable mcp server ([6289bcc](https://github.com/uselark/lark-billing-python/commit/6289bccf0da27dc472d82444b4da00bbe2b071df))
* **api:** update open api ([1d0d34e](https://github.com/uselark/lark-billing-python/commit/1d0d34eadd03f50781d586369e979ca74fbffd13))


### Bug Fixes

* use async_to_httpx_files in patch method ([ca34a23](https://github.com/uselark/lark-billing-python/commit/ca34a23093b621ec1a1c95a7d3be949f6ad37563))


### Chores

* **internal:** add `--fix` argument to lint script ([178176f](https://github.com/uselark/lark-billing-python/commit/178176fd1bf4548ca237acdca7a6786ffffba4a2))
* **internal:** codegen related update ([6e018a3](https://github.com/uselark/lark-billing-python/commit/6e018a372d22639317a6b64b29ee2b7bf56d21ca))

## 0.6.0 (2025-12-18)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/uselark/lark-billing-python/compare/v0.5.0...v0.6.0)

### Features

* **api:** manual updates ([3c29f7c](https://github.com/uselark/lark-billing-python/commit/3c29f7c38832309b7f067097b1ed5e4950e27d9e))


### Chores

* **internal:** add missing files argument to base client ([393fcef](https://github.com/uselark/lark-billing-python/commit/393fceffc009fea461a1765242ef894211e23334))
* speedup initial import ([67d642b](https://github.com/uselark/lark-billing-python/commit/67d642b515132187e51ea2b33478e8ae417fa349))

## 0.5.0 (2025-12-14)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/uselark/lark-billing-python/compare/v0.4.0...v0.5.0)

### Features

* **api:** manual updates ([9715850](https://github.com/uselark/lark-billing-python/commit/9715850187b7e968033a4af2a2cb0f06897909fd))
* **api:** manual updates ([cc6db85](https://github.com/uselark/lark-billing-python/commit/cc6db85be16c1c02e04360fcc25bdfe66dce894d))


### Bug Fixes

* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([ffb09d4](https://github.com/uselark/lark-billing-python/commit/ffb09d4513f0442216c7c62218eb60a8d5e495ee))


### Chores

* add missing docstrings ([bcc85f0](https://github.com/uselark/lark-billing-python/commit/bcc85f031222e12b7435a7183caa7b876f1d3e04))

## 0.4.0 (2025-12-03)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/uselark/lark-billing-python/compare/v0.3.0...v0.4.0)

### Features

* **api:** manual updates ([e7c130c](https://github.com/uselark/lark-billing-python/commit/e7c130c727b09c7e17e93e07583c1316fbab9301))
* **api:** manual updates ([bc92b2f](https://github.com/uselark/lark-billing-python/commit/bc92b2f6869aba820ebede09228bbc89442dd0f1))


### Bug Fixes

* ensure streams are always closed ([8aa8ab0](https://github.com/uselark/lark-billing-python/commit/8aa8ab06bc2f0e78fe192bda8e52c6edfb9f72cf))


### Chores

* add Python 3.14 classifier and testing ([1efbd2c](https://github.com/uselark/lark-billing-python/commit/1efbd2c7571eafde124e9021af7882a8d4d2a0c1))
* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([eb30940](https://github.com/uselark/lark-billing-python/commit/eb309401c595997585b8c91502879075240e32e7))
* **docs:** use environment variables for authentication in code snippets ([4c39099](https://github.com/uselark/lark-billing-python/commit/4c390997fb91a4716238b9ce492947f11594ceb1))
* update lockfile ([e54b4bc](https://github.com/uselark/lark-billing-python/commit/e54b4bc08d6ce82b4f254dfba70fd4c4a90d607d))

## 0.3.0 (2025-11-13)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/uselark/lark-billing-python/compare/v0.2.0...v0.3.0)

### Features

* **api:** manual updates ([59514e8](https://github.com/uselark/lark-billing-python/commit/59514e88e2abb308b1f35fff225bd8020875603f))

## 0.2.0 (2025-11-13)

Full Changelog: [v0.1.5...v0.2.0](https://github.com/uselark/lark-billing-python/compare/v0.1.5...v0.2.0)

### Features

* **api:** manual updates ([e998510](https://github.com/uselark/lark-billing-python/commit/e99851005078fa6b7ac3cdd51c06fe859d22f467))


### Chores

* update SDK settings ([2b29d23](https://github.com/uselark/lark-billing-python/commit/2b29d239f7889ac5d2ed0ac14fec52ffd5a341be))
* update SDK settings ([5c74cc2](https://github.com/uselark/lark-billing-python/commit/5c74cc2085cf19ad7c44c7375933e7f154329991))

## 0.1.5 (2025-11-12)

Full Changelog: [v0.0.1...v0.1.5](https://github.com/uselark/lark-billing-python/compare/v0.0.1...v0.1.5)

### Bug Fixes

* compat with Python 3.14 ([8f570d6](https://github.com/uselark/lark-billing-python/commit/8f570d61379629798ce7684077b7bc4d6689d398))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([f679809](https://github.com/uselark/lark-billing-python/commit/f6798098e2c58bdad0b80ba5592dda300e2c791e))


### Chores

* **package:** drop Python 3.8 support ([3130a60](https://github.com/uselark/lark-billing-python/commit/3130a60a1d96c92efa510700530009792214b146))
* update SDK settings ([271d60d](https://github.com/uselark/lark-billing-python/commit/271d60d4dc7049f43e9e43512212bf3835bb556c))
* update SDK settings ([5df4f4f](https://github.com/uselark/lark-billing-python/commit/5df4f4f944188391e71b902fdffda8cf74e58a05))
* update SDK settings ([57395da](https://github.com/uselark/lark-billing-python/commit/57395da2b788f7c8a866cb0d3eca768267519d23))
